@@ -4,70 +4,88 @@
 <context>
     <name>ImageInterface</name>
     <message>
+        <location filename="ImageInterface.ui" line="14"/>
         <source>Image settings</source>
         <translation>Réglages d&apos;image</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="34"/>
         <source>Width</source>
         <translation>Largeur</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="44"/>
+        <location filename="ImageInterface.ui" line="80"/>
         <source> px</source>
         <translation> px</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="41"/>
         <source>Width of the image (in pixels)</source>
         <translation>Largeur de l&apos;image (en pixels)</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="70"/>
         <source>Height</source>
         <translation>Hauteur</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="77"/>
         <source>Height of the image (in pixels)</source>
         <translation>Hauteur de l&apos;image (en pixels)</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="103"/>
         <source>Image quality</source>
         <translation>Qualité d&apos;image</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="110"/>
         <source>Between 0 (smallest files) and 100 (highest quality)</source>
         <translation>Entre 0 (taille de fichier minimale) et 100 (qualité maximale)</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="146"/>
         <source>Oversampling</source>
         <translation>Suréchantillonage</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="156"/>
         <source>x </source>
         <translation>x </translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="153"/>
         <source>Antialiases image (when larger then 1.0)</source>
         <translation>Anti-alliassage de l&apos;image (si supérieur à 1.0)</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="196"/>
         <source>Use white background</source>
         <translation>Fond blanc</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="193"/>
         <source>Use white as background color</source>
         <translation>Mettre du blanc en couleur de fond</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="206"/>
         <source>Expand frustum if needed</source>
         <translation>Etendre la pyramide de vue ( frustum) si nécessaire</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="203"/>
         <source>When image aspect ratio differs from viewer&apos;s one, expand frustum as needed. Fits inside current frustum otherwise.</source>
         <translation>Lorsque le rapport de dimensions de l&apos;image diffère de celui de la fenêtre, étendre la pyramide de vue (frustum) en conséquence. L&apos;image est ajustée à l&apos;intérieur de la vue actuelle sinon. </translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="247"/>
         <source>OK</source>
         <translation>Ok</translation>
     </message>
     <message>
+        <location filename="ImageInterface.ui" line="254"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
@@ -75,453 +93,557 @@
 <context>
     <name>QGLViewer</name>
     <message>
+        <location filename="qglviewer.cpp" line="77"/>
         <source>snapshot</source>
         <comment>Default snapshot file name</comment>
         <translation>capture</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="85"/>
+        <location filename="qglviewer.cpp" line="407"/>
         <source>%1Hz</source>
         <comment>Frames per seconds, in Hertz</comment>
         <translation>%1Hz</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="517"/>
         <source>Toggles the display of the FPS</source>
         <comment>DISPLAY_FPS action description</comment>
         <translation>Active ou non l&apos;affichage de la fréquence d&apos;affiichage</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="519"/>
         <source>Saves a screenshot</source>
         <comment>SAVE_SCREENSHOT action description</comment>
         <translation>Sauvegarde une capture d&apos;écran</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="521"/>
         <source>Toggles full screen display</source>
         <comment>FULL_SCREEN action description</comment>
         <translation>Passe ou non en mode plein écran</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="522"/>
         <source>Toggles the display of the world axis</source>
         <comment>DRAW_AXIS action description</comment>
         <translation>Affiche ou non le repère du monde</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="525"/>
         <source>Toggles the display of the XY grid</source>
         <comment>DRAW_GRID action description</comment>
         <translation>Affiche ou non la grille XY</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="526"/>
         <source>Changes camera mode (observe or fly)</source>
         <comment>CAMERA_MODE action description</comment>
         <translation>Change le mode de la caméra (observateur ou vol)</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="529"/>
         <source>Toggles stereo display</source>
         <comment>STEREO action description</comment>
         <translation>Affiche ou non en stéréo</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="531"/>
         <source>Opens this help window</source>
         <comment>HELP action description</comment>
         <translation>Ouvre la fenêtre d&apos;aide</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="533"/>
         <source>Starts/stops the animation</source>
         <comment>ANIMATION action description</comment>
         <translation>Démarre/arrête l&apos;animation</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="535"/>
         <source>Toggles camera paths display</source>
         <comment>EDIT_CAMERA action description</comment>
         <translation>Affiche ou non les chemins de caméra</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="538"/>
         <source>Toggles the display of the text</source>
         <comment>ENABLE_TEXT action description</comment>
         <translation>Affiche ou non les textes</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="540"/>
         <source>Exits program</source>
         <comment>EXIT_VIEWER action description</comment>
         <translation>Quitte l&apos;application</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="542"/>
         <source>Moves camera left</source>
         <comment>MOVE_CAMERA_LEFT action description</comment>
         <translation>Déplace la caméra sur la gauche</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="544"/>
         <source>Moves camera right</source>
         <comment>MOVE_CAMERA_RIGHT action description</comment>
         <translation>Déplace la caméra sur la droite</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="546"/>
         <source>Moves camera up</source>
         <comment>MOVE_CAMERA_UP action description</comment>
         <translation>Déplace la caméra vers le haut</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="548"/>
         <source>Moves camera down</source>
         <comment>MOVE_CAMERA_DOWN action description</comment>
         <translation>Déplace la caméra vers le bas</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="550"/>
         <source>Increases fly speed</source>
         <comment>INCREASE_FLYSPEED action description</comment>
         <translation>Augmente la vitesse de vol</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="552"/>
         <source>Decreases fly speed</source>
         <comment>DECREASE_FLYSPEED action description</comment>
         <translation>Diminue la vitesse de vol</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="554"/>
         <source>Copies a snapshot to clipboard</source>
         <comment>SNAPSHOT_TO_CLIPBOARD action description</comment>
         <translation>Place une capture d&apos;écran dans le presse-papier</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1572"/>
         <source>Stereo not supported</source>
         <comment>Message box window title</comment>
         <translation>Stéréo non supportée</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1573"/>
         <source>Stereo is not supported on this display.</source>
         <translation>Affichage en stéréo non supporté sur cette machine.</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1635"/>
         <source>Rotates</source>
         <comment>ROTATE mouse action</comment>
         <translation>Tourne</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1637"/>
         <source>Zooms</source>
         <comment>ZOOM mouse action</comment>
         <translation>Zoome</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1639"/>
         <source>Translates</source>
         <comment>TRANSLATE mouse action</comment>
         <translation>Translate</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1645"/>
         <source>Moves backward</source>
         <comment>MOVE_BACKWARD mouse action</comment>
         <translation>Recule</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1654"/>
         <source>Horizontally/Vertically translates</source>
         <comment>SCREEN_TRANSLATE mouse action</comment>
         <translation>Translate horizontalement/verticalement</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1641"/>
         <source>Moves forward</source>
         <comment>MOVE_FORWARD mouse action</comment>
         <translation>Avance</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1643"/>
         <source>Looks around</source>
         <comment>LOOK_AROUND mouse action</comment>
         <translation>Regarde</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1647"/>
         <source>Rotates in screen plane</source>
         <comment>SCREEN_ROTATE mouse action</comment>
         <translation>Pivote dans le plan écran</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1650"/>
         <source>Rolls</source>
         <comment>ROLL mouse action</comment>
         <translation>Pivote</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1652"/>
         <source>Drives</source>
         <comment>DRIVE mouse action</comment>
         <translation>Avance</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1657"/>
         <source>Zooms on region for</source>
         <comment>ZOOM_ON_REGION mouse action</comment>
         <translation>Zoome sur la région pour</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1667"/>
         <source>Zooms on pixel</source>
         <comment>ZOOM_ON_PIXEL click action</comment>
         <translation>Zoome sur le pixel</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1669"/>
         <source>Zooms to fit scene</source>
         <comment>ZOOM_TO_FIT click action</comment>
         <translation>Zoome pour ajuster à la scène</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1671"/>
         <source>Selects</source>
         <comment>SELECT click action</comment>
         <translation>Sélectionne</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1673"/>
         <source>Sets pivot point</source>
         <comment>RAP_FROM_PIXEL click action</comment>
         <translation>Définit le point de rotation</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1675"/>
         <source>Resets pivot point</source>
         <comment>RAP_IS_CENTER click action</comment>
         <translation>Restaure le point de rotation</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1677"/>
         <source>Centers manipulated frame</source>
         <comment>CENTER_FRAME click action</comment>
         <translation>Centre le repère manipulé</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1680"/>
         <source>Centers scene</source>
         <comment>CENTER_SCENE click action</comment>
         <translation>Centre la scène</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1682"/>
         <source>Shows entire scene</source>
         <comment>SHOW_ENTIRE_SCENE click action</comment>
         <translation>Affiche toute la scène</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1685"/>
         <source>Aligns manipulated frame</source>
         <comment>ALIGN_FRAME click action</comment>
         <translation>Aligne le repère manipulé</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1688"/>
         <source>Aligns camera</source>
         <comment>ALIGN_CAMERA click action</comment>
         <translation>Aligne la caméra</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2105"/>
         <source>Camera paths are controlled using the %1 keys (noted &lt;i&gt;Fx&lt;/i&gt; below):</source>
         <comment>Help window key tab camera keys</comment>
         <translation>Les chemins de caméra sont contrôlés avec les touches %1 (notées &lt;i&gt;Fx&lt;/i&gt; ci-dessous) :</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2057"/>
         <source>Key(s)</source>
         <comment>Keys column header in help window mouse tab</comment>
         <translation>Touche(s)</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1855"/>
+        <location filename="qglviewer.cpp" line="2059"/>
         <source>Description</source>
         <comment>Description column header in help window mouse tab</comment>
         <translation>Description</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2081"/>
         <source>Standard viewer keys</source>
         <comment>In help window keys tab</comment>
         <translation>Raccourcis standards</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2112"/>
+        <location filename="qglviewer.cpp" line="2116"/>
+        <location filename="qglviewer.cpp" line="2120"/>
+        <location filename="qglviewer.cpp" line="2121"/>
         <source>Fx</source>
         <comment>Generic function key (F1..F12)</comment>
         <translation>Fx</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2113"/>
         <source>Plays path (or resets saved position)</source>
         <translation>Joue le chemin (ou restaure la position sauvegardée)</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2117"/>
         <source>Adds a key frame to path (or defines a position)</source>
         <translation>Ajoute une position clef au chemin (ou définit une position)</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2122"/>
         <source>Deletes path (or saved position)</source>
         <translation>Supprime le chemin (ou la position)</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1853"/>
         <source>Button(s)</source>
         <comment>Buttons column header in help window mouse tab</comment>
         <translation>Bouton(s)</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1882"/>
         <source>Standard mouse bindings</source>
         <comment>In help window mouse tab</comment>
         <translation>Actions souris standards</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1721"/>
         <source>Wheel</source>
         <comment>Mouse wheel</comment>
         <translation>Molette</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2152"/>
         <source>&amp;Help</source>
         <comment>Help window tab title</comment>
         <translation>&amp;Aide</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2153"/>
         <source>&amp;Keyboard</source>
         <comment>Help window tab title</comment>
         <translation>&amp;Clavier</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2154"/>
         <source>&amp;Mouse</source>
         <comment>Help window tab title</comment>
         <translation>&amp;Souris</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2160"/>
         <source>Help</source>
         <comment>Help window title</comment>
         <translation>Aide</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2296"/>
         <source>Path %1 deleted</source>
         <comment>Feedback message</comment>
         <translation>Chemin %1 supprimé</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2299"/>
         <source>Position %1 deleted</source>
         <comment>Feedback message</comment>
         <translation>Position %1 supprimée</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2310"/>
         <source>Path %1, position %2 added</source>
         <comment>Feedback message</comment>
         <translation>Chemin %1, position %2 ajoutée</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2315"/>
         <source>Position %1 saved</source>
         <comment>Feedback message</comment>
         <translation>Position %1 sauvegardée</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2374"/>
         <source>Camera in observer mode</source>
         <comment>Feedback message</comment>
         <translation>Caméra en mode observateur</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2375"/>
         <source>Camera in fly mode</source>
         <comment>Feedback message</comment>
         <translation>Caméra en mode vol</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="3733"/>
+        <location filename="qglviewer.cpp" line="3744"/>
+        <location filename="qglviewer.cpp" line="3761"/>
         <source>Save to file error</source>
         <comment>Message box window title</comment>
         <translation>Erreur lors de la sauvegarde</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="3734"/>
         <source>State file name (%1) references a directory instead of a file.</source>
         <translation>Le nom du fichier d&apos;état (%1) référence un répértoire et non un fichier.</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="3745"/>
         <source>Unable to create directory %1</source>
         <translation>Le répértoire %1 ne peut être créé</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="3762"/>
         <source>Unable to save to file %1</source>
         <translation>Impossible de sauvegarder le fichier %1</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="3802"/>
         <source>Problem in state restoration</source>
         <comment>Message box window title</comment>
         <translation>Problème lors de la restauration de l&apos;état</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="3803"/>
         <source>File %1 is not readable.</source>
         <translation>Le fichier %1 n&apos;est pas lisible.</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="3817"/>
         <source>Open file error</source>
         <comment>Message box window title</comment>
         <translation>Erreur d&apos;ouverture de fichier</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="3818"/>
         <source>Unable to open file %1</source>
         <translation>Le fichier %1 ne peut être ouvert</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1216"/>
         <source>Left</source>
         <comment>left mouse button</comment>
         <translation>Gauche</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1222"/>
         <source>Middle</source>
         <comment>middle mouse button</comment>
         <translation>Milieu</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1228"/>
         <source>Right</source>
         <comment>right mouse button</comment>
         <translation>Droit</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1722"/>
         <source> double click</source>
         <comment>Suffix after mouse button</comment>
         <translation>Double clic </translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1901"/>
+        <location filename="qglviewer.cpp" line="1925"/>
         <source>camera</source>
         <comment>Suffix after action</comment>
         <translation>la caméra</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1904"/>
+        <location filename="qglviewer.cpp" line="1928"/>
         <source>manipulated frame</source>
         <comment>Suffix after action</comment>
         <translation>le repère manipulé</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1724"/>
         <source> with </source>
         <comment>As in : Left button with Ctrl pressed</comment>
         <translation> avec </translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1728"/>
         <source> pressed</source>
         <comment>As in : Left button with Ctrl pressed</comment>
         <translation> enfoncé</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="1717"/>
         <source>%1%2%3%4%5%6</source>
         <comment>Modifier / button or wheel / double click / with / button / pressed</comment>
         <translation>%1%3%2%4%5%6</translation>
     </message>
     <message>
+        <location filename="qglviewer.h" line="764"/>
         <source>No help available.</source>
         <translation>Pas d&apos;aide disponible.</translation>
     </message>
     <message>
+        <location filename="VRender/Exporter.cpp" line="24"/>
         <source>Exporter error</source>
         <comment>Message box window title</comment>
         <translation>Erreur d&apos;export</translation>
     </message>
     <message>
+        <location filename="VRender/Exporter.cpp" line="24"/>
         <source>Unable to open file %1.</source>
         <translation>Impossible d&apos;ouvrir le ficher %1.</translation>
     </message>
     <message>
+        <location filename="VRender/BSPSortMethod.cpp" line="53"/>
+        <location filename="VRender/BSPSortMethod.cpp" line="69"/>
         <source>BSP Construction</source>
         <translation>Construction du BSP</translation>
     </message>
     <message>
+        <location filename="VRender/Exporter.cpp" line="45"/>
         <source>Exporting to file %1</source>
         <translation>Export vers le fichier %1</translation>
     </message>
     <message>
+        <location filename="VRender/ParserGL.cpp" line="85"/>
         <source>Parsing feedback buffer.</source>
         <translation>Parcours du feedback buffer.</translation>
     </message>
     <message>
+        <location filename="VRender/TopologicalSortMethod.cpp" line="344"/>
         <source>Topological sort</source>
         <translation>Tri topologique</translation>
     </message>
     <message>
+        <location filename="VRender/TopologicalSortMethod.cpp" line="636"/>
         <source>Advanced topological sort</source>
         <translation>Tri topologique avancé</translation>
     </message>
     <message>
+        <location filename="VRender/VRender.cpp" line="39"/>
         <source>Rendering...</source>
         <translation>Rendu...</translation>
     </message>
     <message>
+        <location filename="VRender/VisibilityOptimizer.cpp" line="221"/>
         <source>Visibility optimization</source>
         <translation>Optimisation de la visibilité</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2155"/>
         <source>&amp;About</source>
         <comment>Help window about title</comment>
         <translation>À &amp;propos</translation>
     </message>
     <message>
+        <location filename="qglviewer.cpp" line="2192"/>
         <source>&lt;h1&gt;libQGLViewer&lt;/h1&gt;&lt;h3&gt;Version %1&lt;/h3&gt;&lt;br&gt;A versatile 3D viewer based on OpenGL and Qt&lt;br&gt;Copyright 2002-%2 Gilles Debunne&lt;br&gt;&lt;code&gt;%3&lt;/code&gt;</source>
         <translation>&lt;h1&gt;libQGLViewer&lt;/h1&gt;&lt;h3&gt;Version %1&lt;/h3&gt;&lt;br&gt;Un afficheur 3D généraliste basé sur OpenGL et Qt&lt;br&gt;Copyright 2002-%2 Gilles Debunne&lt;br&gt;&lt;code&gt;%3&lt;/code&gt;</translation>
     </message>
@@ -529,78 +651,98 @@
 <context>
     <name>VRenderInterface</name>
     <message>
+        <location filename="VRenderInterface.ui" line="14"/>
         <source>Vectorial rendering options</source>
         <translation>Options de rendu vectoriel</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="35"/>
         <source>Include hidden parts</source>
         <translation>Inclure les parties cachées</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="45"/>
         <source>Cull back faces</source>
         <translation>Supprimer les faces arrières</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="42"/>
         <source>Back faces (non clockwise point ordering) are removed from the output</source>
         <translation>Les  faces orientées vers l&apos;arrière (points ordonnés dans le sens anti-horaire) sont supprimées du résultat (Back Face Culling)</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="55"/>
         <source>Black and white</source>
         <translation>Noir et blanc</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="52"/>
         <source>Black and white rendering</source>
         <translation>Rendu en noir et blanc</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="65"/>
         <source>Color background</source>
         <translation>Fond avec une couleur</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="62"/>
         <source>Use current background color instead of white</source>
         <translation>Utiliser la couleur de fond actuelle à la place du blanc</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="75"/>
         <source>Tighten bounding box</source>
         <translation>Ajuster la boîte englobante</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="72"/>
         <source>Fit output bounding box to current display</source>
         <translation>Ajuster la boîte englobante de la sortie à ce qui est actuellement affiché</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="96"/>
+        <location filename="VRenderInterface.ui" line="106"/>
         <source>Polygon depth sorting method</source>
         <translation>Méthode de tri de la profondeur des polygônes</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="113"/>
         <source>No sorting</source>
         <translation>Pas de tri</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="123"/>
         <source>Topological</source>
         <translation>Topologique</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="128"/>
         <source>Advanced topological</source>
         <translation>Topologique avancé</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="156"/>
         <source>Save</source>
         <translation>Sauvegarder</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="163"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="32"/>
         <source>Hidden polygons are also included in the output (usually twice bigger)</source>
         <translation>Inclure les polygônes cachés dans le résultat (alors habituellement deux fois plus gros)</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="99"/>
         <source>Sort method:</source>
         <translation>Méthode de tri :</translation>
     </message>
     <message>
+        <location filename="VRenderInterface.ui" line="118"/>
         <source>BSP</source>
         <translation>BSP</translation>
     </message>
