@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,15 +22,14 @@
 
 #include <qwidgetplugin.h>
 
-class QGLViewerPlugin : public QWidgetPlugin
-{
+class QGLViewerPlugin : public QWidgetPlugin {
 public:
   QStringList keys() const;
-  QWidget *create(const QString& key, QWidget *parent, const char *name);
-  QString group(const QString& key) const;
-  QIconSet iconSet(const QString&) const;
-  QString includeFile(const QString& key) const;
-  QString toolTip(const QString& key) const;
-  QString whatsThis(const QString& key) const;
-  bool isContainer(const QString&) const;
+  QWidget *create(const QString &key, QWidget *parent, const char *name);
+  QString group(const QString &key) const;
+  QIconSet iconSet(const QString &) const;
+  QString includeFile(const QString &key) const;
+  QString toolTip(const QString &key) const;
+  QString whatsThis(const QString &key) const;
+  bool isContainer(const QString &) const;
 };
