@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -27,21 +27,20 @@
 
 using namespace std;
 
-void help()
-{
+void help() {
   QString text("<h2>C a l l b a c k</h2>");
   text += "This example is conceptually the same as simpleViewer.<br>";
   text += "The difference is that it uses the Qt signal/slot mechanism ";
   text += "instead of deriving the QGLViewer class. ";
-  text += "The QGLViewer::drawNeeded() signal is connected to the Scene::draw() method. ";
+  text += "The QGLViewer::drawNeeded() signal is connected to the "
+          "Scene::draw() method. ";
   text += "The two classes are otherwise completely independant.";
 
   QMessageBox::information(NULL, "Callback exemple", text);
 }
 
-int main(int argc, char** argv)
-{
-  QApplication application(argc,argv);
+int main(int argc, char **argv) {
+  QApplication application(argc, argv);
 
   // Instantiate the viewer.
   QGLViewer viewer;
