@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -23,10 +23,9 @@
 #include "cameraLight.h"
 #include <qapplication.h>
 
-int main(int argc, char** argv)
-{
+int main(int argc, char **argv) {
   // Read command lines arguments.
-  QApplication application(argc,argv);
+  QApplication application(argc, argv);
 
   // Instantiate the viewer.
   Viewer viewer;
