@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,8 +22,7 @@
 
 #include <QGLViewer/qglviewer.h>
 
-class Viewer : public QGLViewer
-{
+class Viewer : public QGLViewer {
 protected:
   virtual void init();
   virtual void draw();
@@ -31,19 +30,23 @@ protected:
   virtual void keyPressEvent(QKeyEvent *);
 
   void displayText();
-  void displayType(const qglviewer::AxisPlaneConstraint::Type type, const int x, const int y, const char c);
-  void displayDir(const unsigned short dir, const int x, const int y, const char c);
+  void displayType(const qglviewer::AxisPlaneConstraint::Type type, const int x,
+                   const int y, const char c);
+  void displayDir(const unsigned short dir, const int x, const int y,
+                  const char c);
 
 private:
   int transDir;
   int rotDir;
 
-  qglviewer::ManipulatedFrame* frame;
+  qglviewer::ManipulatedFrame *frame;
 
-  static qglviewer::AxisPlaneConstraint::Type nextTranslationConstraintType(const qglviewer::AxisPlaneConstraint::Type& type);
-  static qglviewer::AxisPlaneConstraint::Type nextRotationConstraintType(const qglviewer::AxisPlaneConstraint::Type& type);
+  static qglviewer::AxisPlaneConstraint::Type nextTranslationConstraintType(
+      const qglviewer::AxisPlaneConstraint::Type &type);
+  static qglviewer::AxisPlaneConstraint::Type
+  nextRotationConstraintType(const qglviewer::AxisPlaneConstraint::Type &type);
 
   void changeConstraint();
-  qglviewer::AxisPlaneConstraint* constraints[3];
+  qglviewer::AxisPlaneConstraint *constraints[3];
   unsigned short activeConstraint;
 };
