@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -20,24 +20,25 @@
 
 *****************************************************************************/
 
+#include "../Viewer/board.h"
 #include <fstream>
 #include <stdio.h>
-#include "../Viewer/board.h"
 
-int main (int argc, char ** argv)
-{    
+int main(int argc, char **argv) {
   if (argc != 4) {
-	  std::cout << "This AI agora player requires 3 parameters. It should be called by the main agora viewer application." << std::endl;
-	  exit(1);
+    std::cout << "This AI agora player requires 3 parameters. It should be "
+                 "called by the main agora viewer application."
+              << std::endl;
+    exit(1);
   }
-  
+
   Board board;
 
   std::ifstream file(argv[1]);
   file >> board;
   file.close();
 
-  std::cout << board.randomMove(QString(argv[2]).toInt()>=0) << std::endl;
+  std::cout << board.randomMove(QString(argv[2]).toInt() >= 0) << std::endl;
 
   return 0;
 }
