@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,25 +22,22 @@
 
 #include "move.h"
 #include "board.h"
-#include "qstringlist.h"
 #include "qregexp.h"
+#include "qstringlist.h"
 
 #include "QGLViewer/keyFrameInterpolator.h"
 using namespace qglviewer;
 
-Move::Move(const QPoint& s, const QPoint& e, bool under)
-: start_(s), end_(e), under_(under)
-{}
+Move::Move(const QPoint &s, const QPoint &e, bool under)
+    : start_(s), end_(e), under_(under) {}
 
-Move::Move(const Board* const b, int s, int e, bool under)
-{
+Move::Move(const Board *const b, int s, int e, bool under) {
   start_ = b->pointFromInt(s);
-  end_   = b->pointFromInt(e);
+  end_ = b->pointFromInt(e);
   under_ = under;
 }
 
-Move::Move(const QString text)
-{
+Move::Move(const QString text) {
 #if QT_VERSION < 0x040000
   QStringList list = QStringList::split(QRegExp("\\D+"), text);
 #else
@@ -53,36 +50,34 @@ Move::Move(const QString text)
   under_ = text.contains('<');
 }
 
-bool Move::isValid(const Board* const b) const
-{
-  if (b->isValid(start()) &&
-	  b->isValid(end()) &&
-	  abs(start().x()-end().x()) <= 1 &&
-	  abs(start().y()-end().y()) <= 1 &&
-	  start() != end() &&
-	  b->caseAt(start()).nbTop() > 0 &&
-	  b->caseAt(start()).topIsBlack() == b->blackPlays()) {
-	  if (goesUnder())
-		  return ((b->caseAt(start()).topAltitude() <= b->caseAt(end()).topAltitude()) && 
-				  (b->caseAt(end()).nbTop() > 0) &&
-				  (b->caseAt(end()).topIsBlack() != b->blackPlays()));
-	  else
-		  return ((b->caseAt(end()).nbTop() == 0) || 
-		          ((b->caseAt(start()).topAltitude() >= b->caseAt(end()).topAltitude()) && (b->caseAt(end()).topIsBlack() != b->blackPlays()))); 
+bool Move::isValid(const Board *const b) const {
+  if (b->isValid(start()) && b->isValid(end()) &&
+      abs(start().x() - end().x()) <= 1 && abs(start().y() - end().y()) <= 1 &&
+      start() != end() && b->caseAt(start()).nbTop() > 0 &&
+      b->caseAt(start()).topIsBlack() == b->blackPlays()) {
+    if (goesUnder())
+      return ((b->caseAt(start()).topAltitude() <=
+               b->caseAt(end()).topAltitude()) &&
+              (b->caseAt(end()).nbTop() > 0) &&
+              (b->caseAt(end()).topIsBlack() != b->blackPlays()));
+    else
+      return ((b->caseAt(end()).nbTop() == 0) ||
+              ((b->caseAt(start()).topAltitude() >=
+                b->caseAt(end()).topAltitude()) &&
+               (b->caseAt(end()).topIsBlack() != b->blackPlays())));
   }
   return false;
 }
 
-void Move::updateBoard(const Board* b) const
-{
-	// No tests here, assume move is valid
-    b->caseAt(start()).removePiece();
-    b->caseAt(end()).addPiece(goesUnder(), b->blackPlays());
+void Move::updateBoard(const Board *b) const {
+  // No tests here, assume move is valid
+  b->caseAt(start()).removePiece();
+  b->caseAt(end()).addPiece(goesUnder(), b->blackPlays());
 }
 
-std::ostream& operator<<(std::ostream& out, const Move& m)
-{
-  out << "((" << m.start().x() << "," << m.start().y() << ")" << (m.goesUnder()?"<":">") << "(" << m.end().x() << ","<< m.end().y() << "))" << std::endl;
+std::ostream &operator<<(std::ostream &out, const Move &m) {
+  out << "((" << m.start().x() << "," << m.start().y() << ")"
+      << (m.goesUnder() ? "<" : ">") << "(" << m.end().x() << "," << m.end().y()
+      << "))" << std::endl;
   return out;
 }
-
