@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -28,28 +28,27 @@
 #include <iostream>
 
 #if QT_VERSION < 0x040000
-# include <qvaluevector.h>
+#include <qvaluevector.h>
 #else
-# include <qstringlist.h> 
+#include <qstringlist.h>
 #endif
 
-class Undo
-{
+class Undo {
 public:
   Undo() { clear(); }
 
   void clear();
-  void addState(const QString& s);
-  
+  void addState(const QString &s);
+
   QString undoState();
   QString redoState();
 
   bool isEmpty() const { return state_.isEmpty(); };
 
   int nbMoves() const { return index_; };
-  
-  friend std::ostream& operator<<(std::ostream& out, const Undo& u);
-  friend std::istream& operator>>(std::istream& in, Undo& u);
+
+  friend std::ostream &operator<<(std::ostream &out, const Undo &u);
+  friend std::istream &operator>>(std::istream &in, Undo &u);
 
 private:
 #if QT_VERSION < 0x040000
