@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,8 +22,7 @@
 
 #include "QGLViewer/qglviewer.h"
 
-class Viewer : public QGLViewer
-{
+class Viewer : public QGLViewer {
 protected:
   virtual void draw();
   virtual void init();
