@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -29,39 +29,38 @@
 class ComputerPlayerInterface;
 class QProcess;
 
-class ComputerPlayer : public QObject
-{
+class ComputerPlayer : public QObject {
   Q_OBJECT
-  
+
 public:
   ComputerPlayer();
   ~ComputerPlayer();
-  
+
   bool isActive() const { return isActive_; }
   void setIsActive(bool on);
-  
+
   int allowedTime() const;
   void setAllowedTime(int time);
 
   QString programFileName() const;
-  void setProgramFileName(const QString& name);
+  void setProgramFileName(const QString &name);
 
   void configure();
 
-  void play(bool blue, const QString& stateFileName);
+  void play(bool blue, const QString &stateFileName);
 
 public:
-  Q_SIGNALS:
+Q_SIGNALS:
   void moveMade(QString move, int duration);
- 
+
 private Q_SLOTS:
   void selectProgram();
   void readFromStdout();
-  
+
 private:
   bool isActive_;
-  ComputerPlayerInterface* interface_;
-  QProcess* process_;
+  ComputerPlayerInterface *interface_;
+  QProcess *process_;
 };
 
 #endif // COMPUTER_PLAYER_H
