@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -23,26 +23,24 @@
 #include <qapplication.h>
 
 #if QT_VERSION >= 0x040000
-# include "ui_blobWarWindow.h"
-  class BlobWarWindow : public QMainWindow, public Ui::BlobWarWindow
-  {
-  public:
-    BlobWarWindow() { setupUi(this); }
-  };
+#include "ui_blobWarWindow.h"
+class BlobWarWindow : public QMainWindow, public Ui::BlobWarWindow {
+public:
+  BlobWarWindow() { setupUi(this); }
+};
 #else
-# if QT_VERSION >= 0x030000
-#  include "blobWarWindow.Qt3.h"
-# else
-#  error "No .ui file available for Qt 2"
-# endif
+#if QT_VERSION >= 0x030000
+#include "blobWarWindow.Qt3.h"
+#else
+#error "No .ui file available for Qt 2"
+#endif
 #endif
 
-int main(int argc, char * argv[])
-{
-  QApplication application(argc,argv);
+int main(int argc, char *argv[]) {
+  QApplication application(argc, argv);
 
   BlobWarWindow bww;
-  
+
 #if QT_VERSION < 0x040000
   application.setMainWidget(&bww);
 #else
@@ -50,7 +48,6 @@ int main(int argc, char * argv[])
 #endif
 
   bww.show();
-  
+
   return application.exec();
 }
-
