@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -23,19 +23,18 @@
 #include "dvonnviewer.h"
 #include "dvonnwindowimpl.h"
 #include "game.h"
+#include <qaction.h>
 #include <qapplication.h>
 #include <qmenubar.h>
-#include <qaction.h>
 
 using namespace dvonn;
 
-int main(int argc, char * argv[])
-{
-  QApplication application(argc,argv);
+int main(int argc, char *argv[]) {
+  QApplication application(argc, argv);
 
   Game game;
   DvonnWindowImpl mainWindow(&game);
-  
+
 #if QT_VERSION < 0x040000
   application.setMainWidget(&mainWindow);
 #else
@@ -46,4 +45,3 @@ int main(int argc, char * argv[])
 
   return application.exec();
 }
-
