@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,81 +22,82 @@
 
 #include "jeu.h"
 
-bool Jeu::needDrawing(int i)
-{ return tab[i].empty; }
+bool Jeu::needDrawing(int i) { return tab[i].empty; }
 
-void Jeu::placePiece(int select, Piece *p)
-{
+void Jeu::placePiece(int select, Piece *p) {
   // on verifie que la piece n'ai pas été déja placée autre part
-  for(int i=0; i<16; i++)
-    if(tab[i].piece==p) {
-      if(i==select) return; // la piece a déja été placée au bon endroit
+  for (int i = 0; i < 16; i++)
+    if (tab[i].piece == p) {
+      if (i == select)
+        return; // la piece a déja été placée au bon endroit
       // si oui, on l'enlève
-      tab[i].empty=true;
-      tab[i].piece=NULL;
+      tab[i].empty = true;
+      tab[i].piece = NULL;
     }
   // on place la piece
-  tab[select].empty=false;
-  tab[select].piece=p;
+  tab[select].empty = false;
+  tab[select].piece = p;
 }
 
 // Vrai ssi les 4 pieces ont unbe caractéristique commune
-bool Jeu::caracCommune(Piece* pieces[4])
-{
-  for (int i=0; i<4; ++i)
+bool Jeu::caracCommune(Piece *pieces[4]) {
+  for (int i = 0; i < 4; ++i)
     if (!pieces[i])
       return false;
 
   // sinon on teste les caracteristiques communes
   // la taille
-  if (pieces[0]->getTaille()==pieces[1]->getTaille() &&
-      pieces[0]->getTaille()==pieces[2]->getTaille() &&
-      pieces[0]->getTaille()==pieces[3]->getTaille()) return true;
+  if (pieces[0]->getTaille() == pieces[1]->getTaille() &&
+      pieces[0]->getTaille() == pieces[2]->getTaille() &&
+      pieces[0]->getTaille() == pieces[3]->getTaille())
+    return true;
   // la couleur
-  if (pieces[0]->getCouleur()==pieces[1]->getCouleur() &&
-      pieces[0]->getCouleur()==pieces[2]->getCouleur() &&
-      pieces[0]->getCouleur()==pieces[3]->getCouleur()) return true;
+  if (pieces[0]->getCouleur() == pieces[1]->getCouleur() &&
+      pieces[0]->getCouleur() == pieces[2]->getCouleur() &&
+      pieces[0]->getCouleur() == pieces[3]->getCouleur())
+    return true;
   // la forme
-  if (pieces[0]->getForme()==pieces[1]->getForme() &&
-      pieces[0]->getForme()==pieces[2]->getForme() &&
-      pieces[0]->getForme()==pieces[3]->getForme()) return true;
+  if (pieces[0]->getForme() == pieces[1]->getForme() &&
+      pieces[0]->getForme() == pieces[2]->getForme() &&
+      pieces[0]->getForme() == pieces[3]->getForme())
+    return true;
   // le trou
-  if (pieces[0]->getTrou()==pieces[1]->getTrou() &&
-      pieces[0]->getTrou()==pieces[2]->getTrou() &&
-      pieces[0]->getTrou()==pieces[3]->getTrou()) return true;
+  if (pieces[0]->getTrou() == pieces[1]->getTrou() &&
+      pieces[0]->getTrou() == pieces[2]->getTrou() &&
+      pieces[0]->getTrou() == pieces[3]->getTrou())
+    return true;
 
   return false;
 }
 
 // Analyse si un alignement a été effectué
-bool Jeu::analyze()
-{
-  Piece* pieces[4];
+bool Jeu::analyze() {
+  Piece *pieces[4];
 
   // on teste les lignes //
-  for(int j=0; j<4; j++) {
-    for (int i=0; i<4; ++i)
-      pieces[i] = tab[j*4+i].piece;
+  for (int j = 0; j < 4; j++) {
+    for (int i = 0; i < 4; ++i)
+      pieces[i] = tab[j * 4 + i].piece;
     if (caracCommune(pieces))
       return true;
   }
 
   // on teste les colonnes //
-  for(int j=0; j<4; j++) {
-    for (int i=0; i<4; ++i)
-      pieces[i] = tab[4*i+j].piece;
+  for (int j = 0; j < 4; j++) {
+    for (int i = 0; i < 4; ++i)
+      pieces[i] = tab[4 * i + j].piece;
     if (caracCommune(pieces))
       return true;
   }
 
   // on teste les diagonales //
-  for (int i=0; i<4; ++i)
-    pieces[i] = tab[5*i].piece;
+  for (int i = 0; i < 4; ++i)
+    pieces[i] = tab[5 * i].piece;
   if (caracCommune(pieces))
     return true;
 
-  for (int i=0; i<4; ++i)
-    pieces[i] = tab[3*(i+1)].piece;
+  for (int i = 0; i < 4; ++i)
+    pieces[i] = tab[3 * (i + 1)].piece;
   if (caracCommune(pieces))
     return true;
 
