@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -23,9 +23,8 @@
 #include "quarto.h"
 #include <qapplication.h>
 
-int main( int argc, char ** argv )
-{
-  QApplication app( argc, argv );
+int main(int argc, char **argv) {
+  QApplication app(argc, argv);
 
   Quarto *quarto = new Quarto;
 
@@ -39,4 +38,3 @@ int main( int argc, char ** argv )
 
   return app.exec();
 }
-
