@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -21,7 +21,7 @@
 *****************************************************************************/
 
 // TP OpenGL: Joerg Liebelt, Serigne Sow
-//on ajoute du ciel!
+// on ajoute du ciel!
 #ifndef __SKYBOX_H__
 #define __SKYBOX_H__
 
@@ -30,41 +30,37 @@
 
 #define SKY_SIDES 6
 
-#define SKY_FRONT  0
-#define SKY_BACK   1
-#define SKY_RIGHT  2
-#define SKY_LEFT   3
-#define SKY_TOP    4
+#define SKY_FRONT 0
+#define SKY_BACK 1
+#define SKY_RIGHT 2
+#define SKY_LEFT 3
+#define SKY_TOP 4
 #define SKY_BOTTOM 5
 
-
-class SKY
-{
+class SKY {
 private:
-  QImage textures[SKY_SIDES];	//les cotes du ciel
-  GLuint texIDs[SKY_SIDES];		//les IDs opengl pour chaque texture
+  QImage textures[SKY_SIDES]; // les cotes du ciel
+  GLuint texIDs[SKY_SIDES];   // les IDs opengl pour chaque texture
   qglviewer::Vec vecMin, vecMax, vecCenter;
   bool iwantsky;
 
 public:
   SKY() { iwantsky = false; }
 
-  bool LoadTexture( int side, const QString& filename );
+  bool LoadTexture(int side, const QString &filename);
 
   void Render();
 
-  //parametres du ciel
-  void Set( float X, float Y, float Z, float size )
-  {
-    vecCenter.setValue( X, Y, Z );
+  // parametres du ciel
+  void Set(float X, float Y, float Z, float size) {
+    vecCenter.setValue(X, Y, Z);
 
-    vecMin.setValue( 0, 0, 0 );
-    vecMax.setValue( size, size, size );
+    vecMin.setValue(0, 0, 0);
+    vecMax.setValue(size, size, size);
   }
 
   void switchSky() { iwantsky = !iwantsky; }
   bool wantSky() { return iwantsky; }
 };
 
-
 #endif
