@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -21,34 +21,33 @@
 *****************************************************************************/
 
 // TP OpenGL: Joerg Liebelt, Serigne Sow
-//on ajoute des arbres
+// on ajoute des arbres
 #ifndef __TREEBOX_H__
 #define __TREEBOX_H__
 
 #include "quadtree.h"
 
-class TREE
-{
+class TREE {
 private:
   QImage texture;
   GLuint texID;
   bool iwanttrees;
   float treeSizeFactor;
   int numTrees;
-  qglviewer::Vec* treeInfo;
-  //ici, je casse la beaute de mon architecture car avec la ligne suivante,
-  //...TREE depend de QUADTREE et n'est plus independant de la maniere dont le terrain a ete cree. dommage..
-  QUADTREE myTerrain;		//pour recuperer l'hauteur du terrain
+  qglviewer::Vec *treeInfo;
+  // ici, je casse la beaute de mon architecture car avec la ligne suivante,
+  //...TREE depend de QUADTREE et n'est plus independant de la maniere dont le
+  //terrain a ete cree. dommage..
+  QUADTREE myTerrain; // pour recuperer l'hauteur du terrain
 
 public:
-  TREE()
-  {
+  TREE() {
     iwanttrees = false;
     treeSizeFactor = 0.05f;
     numTrees = 20;
   }
 
-  bool LoadTexture(const QString& filename );
+  bool LoadTexture(const QString &filename);
 
   void initTrees(QUADTREE ter, int num, float waterLevel);
 
@@ -57,8 +56,6 @@ public:
   void switchTree() { iwanttrees = !iwanttrees; }
 
   bool wantTree() { return iwanttrees; }
-
 };
 
-
 #endif
