@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -26,25 +26,22 @@
 
 #include <QGLViewer/qglviewer.h>
 
-class Viewer : public QGLViewer
-{
+class Viewer : public QGLViewer {
 private:
   bool drawMesh;
 
-protected :
+protected:
   virtual void draw();
   virtual void init();
-  virtual void animate();		//pour l'eau
+  virtual void animate(); // pour l'eau
   virtual QString helpString() const;
 
-  bool CheckExtension(const QString& szExtensionName );	//CODE EXTERNE
+  bool CheckExtension(const QString &szExtensionName); // CODE EXTERNE
 
 public:
-  bool DrawInit( void );
-  bool DrawShutdown( void );
+  bool DrawInit(void);
+  bool DrawShutdown(void);
   void keyPressEvent(QKeyEvent *e);
 };
 
-
 #endif
-
