@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -23,9 +23,8 @@
 #include "textureViewer.h"
 #include <qapplication.h>
 
-int main(int argc, char** argv)
-{
-  QApplication application(argc,argv);
+int main(int argc, char **argv) {
+  QApplication application(argc, argv);
 
   Viewer viewer;
 
@@ -36,6 +35,6 @@ int main(int argc, char** argv)
 #endif
 
   viewer.show();
-  
+
   return application.exec();
 }
