@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,16 +22,17 @@
 
 #include <QGLViewer/camera.h>
 
-class CullingCamera : public qglviewer::Camera
-{
+class CullingCamera : public qglviewer::Camera {
 public:
+  void computeFrustumPlanesEquations() const {
+    getFrustumPlanesCoefficients(planeCoefficients);
+  }
 
-  void computeFrustumPlanesEquations() const { getFrustumPlanesCoefficients(planeCoefficients); }
+  float distanceToFrustumPlane(int index, const qglviewer::Vec &pos) const;
+  bool sphereIsVisible(const qglviewer::Vec &center, float radius) const;
+  bool aaBoxIsVisible(const qglviewer::Vec &p1, const qglviewer::Vec &p2,
+                      bool *entirely = NULL) const;
 
-  float distanceToFrustumPlane(int index, const qglviewer::Vec& pos) const;
-  bool sphereIsVisible(const qglviewer::Vec& center, float radius) const;
-  bool aaBoxIsVisible(const qglviewer::Vec& p1, const qglviewer::Vec& p2, bool* entirely=NULL) const;
-  
 private:
   // F r u s t u m   p l a n e s
   mutable GLdouble planeCoefficients[6][4];
