@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -21,52 +21,50 @@
 *****************************************************************************/
 
 #include "frustumCulling.h"
-#include "cullingCamera.h"
 #include "box.h"
+#include "cullingCamera.h"
 
 using namespace qglviewer;
 
-void Viewer::draw()
-{
+void Viewer::draw() {
   Box::Root->drawIfAllChildrenAreVisible(cullingCamera);
 
   if (cullingCamera == camera())
     // Main viewer computes its plane equation
     cullingCamera->computeFrustumPlanesEquations();
-  else
-    {
-      // Observer viewer draws cullingCamera
-      glLineWidth(4.0);
-      glColor4f(1.0, 1.0, 1.0, 0.5);
-      cullingCamera->draw();
-    }
+  else {
+    // Observer viewer draws cullingCamera
+    glLineWidth(4.0);
+    glColor4f(1.0, 1.0, 1.0, 0.5);
+    cullingCamera->draw();
+  }
 }
 
-void Viewer::init()
-{
+void Viewer::init() {
   // Restore previous viewer state.
   restoreStateFromFile();
 
-  if (cullingCamera != camera())
-    {
-      // Observer viewer configuration
-      glEnable(GL_BLEND);
-      glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-      help();
-    }
-  
+  if (cullingCamera != camera()) {
+    // Observer viewer configuration
+    glEnable(GL_BLEND);
+    glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+    help();
+  }
+
   glDisable(GL_LIGHTING);
 }
 
-QString Viewer::helpString() const
-{
+QString Viewer::helpString() const {
   QString text("<h2>F r u s t u m C u l l i n g</h2>");
 
-  text += "A hierarchical octree structure is clipped against the camera's frustum clipping planes, obtained ";
-  text += "using <code>getFrustumPlanesCoefficients</code>. A second viewer uses <code>drawCamera()</code> to ";
+  text += "A hierarchical octree structure is clipped against the camera's "
+          "frustum clipping planes, obtained ";
+  text += "using <code>getFrustumPlanesCoefficients</code>. A second viewer "
+          "uses <code>drawCamera()</code> to ";
   text += "display an external view of the first viewer's camera.<br><br>";
 
-  text += "This frustum culling implementation is quite naive. Many optimisation techniques are available in ";
+  text += "This frustum culling implementation is quite naive. Many "
+          "optimisation techniques are available in ";
   text += "the litterature.";
 
   return text;
