@@ -1,8 +1,8 @@
 /****************************************************************************
 
- Copyright (C) 2002-2013 Gilles Debunne. All rights reserved.
+ Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.5.0.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -24,16 +24,15 @@
 
 class CullingCamera;
 
-class Viewer : public QGLViewer
-{
+class Viewer : public QGLViewer {
 public:
-  void setCullingCamera(const CullingCamera* const cc) { cullingCamera = cc; }
-  
+  void setCullingCamera(const CullingCamera *const cc) { cullingCamera = cc; }
+
 protected:
   virtual void draw();
   virtual void init();
   virtual QString helpString() const;
 
 private:
-  const CullingCamera* cullingCamera;
+  const CullingCamera *cullingCamera;
 };
