@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,34 +22,31 @@
 
 #include "keyFrames.h"
 
-#include <QKeyEvent>
 #include <QGLViewer/manipulatedFrame.h>
+#include <QKeyEvent>
 
 using namespace qglviewer;
 using namespace std;
 
-Viewer::Viewer()
-  : nbKeyFrames(4)
-{
+Viewer::Viewer() : nbKeyFrames(4) {
   restoreStateFromFile();
 
   // myFrame is the Frame that will be interpolated.
-  Frame* myFrame = new Frame();
+  Frame *myFrame = new Frame();
 
   // Set myFrame as the KeyFrameInterpolator interpolated Frame.
   kfi_.setFrame(myFrame);
   kfi_.setLoopInterpolation();
 
   // An array of manipulated (key) frames.
-  keyFrame_ = new ManipulatedFrame*[nbKeyFrames];
+  keyFrame_ = new ManipulatedFrame *[nbKeyFrames];
 
   // Create an initial path
-  for (int i=0; i<nbKeyFrames; i++)
-	{
-	  keyFrame_[i] = new ManipulatedFrame();
-	  keyFrame_[i]->setPosition(-1.0 + 2.0*i/(nbKeyFrames-1), 0.0, 0.0);
-	  kfi_.addKeyFrame(keyFrame_[i]);
-	}
+  for (int i = 0; i < nbKeyFrames; i++) {
+    keyFrame_[i] = new ManipulatedFrame();
+    keyFrame_[i]->setPosition(-1.0 + 2.0 * i / (nbKeyFrames - 1), 0.0, 0.0);
+    kfi_.addKeyFrame(keyFrame_[i]);
+  }
 
   currentKF_ = 0;
   setManipulatedFrame(keyFrame_[currentKF_]);
@@ -65,58 +62,59 @@ Viewer::Viewer()
 
   help();
 
-  connect(&kfi_, SIGNAL(interpolated()), SLOT(updateGL()));
+  connect(&kfi_, SIGNAL(interpolated()), SLOT(update()));
   kfi_.startInterpolation();
 }
 
-QString Viewer::helpString() const
-{
+QString Viewer::helpString() const {
   QString text("<h2>K e y F r a m e s</h2>");
-  text += "A <i>KeyFrameInterpolator</i> holds an interpolated path defined by key frames. ";
-  text += "It can then smoothly make its associed frame follow that path. Key frames can interactively be manipulated, even ";
+  text += "A <i>KeyFrameInterpolator</i> holds an interpolated path defined by "
+          "key frames. ";
+  text += "It can then smoothly make its associed frame follow that path. Key "
+          "frames can interactively be manipulated, even ";
   text += "during interpolation.<br><br>";
-  text += "Note that the camera holds 12 such keyFrameInterpolators, binded to F1-F12. Press <b>Alt+Fx</b> to define new key ";
-  text += "frames, and then press <b>Fx</b> to make the camera follow the path. Press <b>C</b> to visualize these paths.<br><br>";
-  text += "<b>+/-</b> changes the interpolation speed. Negative values are allowed.<br><br>";
+  text += "Note that the camera holds 12 such keyFrameInterpolators, binded to "
+          "F1-F12. Press <b>Alt+Fx</b> to define new key ";
+  text += "frames, and then press <b>Fx</b> to make the camera follow the "
+          "path. Press <b>C</b> to visualize these paths.<br><br>";
+  text += "<b>+/-</b> changes the interpolation speed. Negative values are "
+          "allowed.<br><br>";
   text += "<b>Return</b> starts-stops the interpolation.<br><br>";
   text += "Use the left and right arrows to change the manipulated KeyFrame. ";
   text += "Press <b>Control</b> to move it or simply hover over it.";
   return text;
 }
 
-void Viewer::keyPressEvent(QKeyEvent *e)
-{
-  switch (e->key())
-	{
-	case Qt::Key_Left :
-	  currentKF_ = (currentKF_+nbKeyFrames-1) % nbKeyFrames;
-	  setManipulatedFrame(keyFrame_[currentKF_]);
-	  updateGL();
-	  break;
-	case Qt::Key_Right :
-	  currentKF_ = (currentKF_+1) % nbKeyFrames;
-	  setManipulatedFrame(keyFrame_[currentKF_]);
-	  updateGL();
-	  break;
-	case Qt::Key_Return :
-	  kfi_.toggleInterpolation();
-	  break;
-	case Qt::Key_Plus :
-	  kfi_.setInterpolationSpeed(kfi_.interpolationSpeed()+0.25);
-	  break;
-	case Qt::Key_Minus :
-	  kfi_.setInterpolationSpeed(kfi_.interpolationSpeed()-0.25);
-	  break;
-	// case Qt::Key_C :
-	  // kfi_.setClosedPath(!kfi_.closedPath());
-	  // break;
-	default:
-	  QGLViewer::keyPressEvent(e);
-	}
+void Viewer::keyPressEvent(QKeyEvent *e) {
+  switch (e->key()) {
+  case Qt::Key_Left:
+    currentKF_ = (currentKF_ + nbKeyFrames - 1) % nbKeyFrames;
+    setManipulatedFrame(keyFrame_[currentKF_]);
+    update();
+    break;
+  case Qt::Key_Right:
+    currentKF_ = (currentKF_ + 1) % nbKeyFrames;
+    setManipulatedFrame(keyFrame_[currentKF_]);
+    update();
+    break;
+  case Qt::Key_Return:
+    kfi_.toggleInterpolation();
+    break;
+  case Qt::Key_Plus:
+    kfi_.setInterpolationSpeed(kfi_.interpolationSpeed() + 0.25);
+    break;
+  case Qt::Key_Minus:
+    kfi_.setInterpolationSpeed(kfi_.interpolationSpeed() - 0.25);
+    break;
+  // case Qt::Key_C :
+  // kfi_.setClosedPath(!kfi_.closedPath());
+  // break;
+  default:
+    QGLViewer::keyPressEvent(e);
+  }
 }
 
-void Viewer::draw()
-{
+void Viewer::draw() {
   // Draw interpolated frame
   glPushMatrix();
   glMultMatrixd(kfi_.frame()->matrix());
@@ -125,16 +123,15 @@ void Viewer::draw()
 
   kfi_.drawPath(5, 10);
 
-  for (int i=0; i<nbKeyFrames; ++i)
-	{
-	  glPushMatrix();
-	  glMultMatrixd(kfi_.keyFrame(i).matrix());
+  for (int i = 0; i < nbKeyFrames; ++i) {
+    glPushMatrix();
+    glMultMatrixd(kfi_.keyFrame(i).matrix());
 
-	  if ((i == currentKF_) || (keyFrame_[i]->grabsMouse()))
-	drawAxis(0.4f);
-	  else
-	drawAxis(0.2f);
+    if ((i == currentKF_) || (keyFrame_[i]->grabsMouse()))
+      drawAxis(0.4f);
+    else
+      drawAxis(0.2f);
 
-	  glPopMatrix();
-	}
+    glPopMatrix();
+  }
 }
