@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,18 +22,17 @@
 
 #include <QGLViewer/qglviewer.h>
 
-class Viewer : public QGLViewer
-{
-public :
+class Viewer : public QGLViewer {
+public:
   Viewer();
 
-protected :
+protected:
   virtual void draw();
   virtual void keyPressEvent(QKeyEvent *e);
   virtual QString helpString() const;
 
-private :
-  qglviewer::ManipulatedFrame** keyFrame_;
+private:
+  qglviewer::ManipulatedFrame **keyFrame_;
   qglviewer::KeyFrameInterpolator kfi_;
   const int nbKeyFrames;
   int currentKF_;
