@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,19 +22,18 @@
 
 #include <QGLViewer/qglviewer.h>
 
-class Viewer : public QGLViewer
-{
+class Viewer : public QGLViewer {
 public:
-  Viewer() : wireframe_(false), flatShading_(false) {};
+  Viewer() : wireframe_(false), flatShading_(false){};
 
-protected :
+protected:
   virtual void draw();
   virtual void init();
   virtual void keyPressEvent(QKeyEvent *e);
-  virtual void mousePressEvent(QMouseEvent* e);
+  virtual void mousePressEvent(QMouseEvent *e);
 
   virtual QString helpString() const;
 
-private :
+private:
   bool wireframe_, flatShading_;
 };
