@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,19 +22,18 @@
 
 #include <QGLViewer/qglviewer.h>
 
-class Luxo
-{
-public :
+class Luxo {
+public:
   Luxo();
 
-  void draw(bool names=false);
+  void draw(bool names = false);
 
-  qglviewer::ManipulatedFrame* frame(unsigned short i) { return frame_[i]; }
+  qglviewer::ManipulatedFrame *frame(unsigned short i) { return frame_[i]; }
   void setSelectedFrameNumber(unsigned short nb) { selected = nb; }
 
-private :
+private:
   // The four articulations of the lamp
-  qglviewer::ManipulatedFrame* frame_[4];
+  qglviewer::ManipulatedFrame *frame_[4];
   // Used to draw the selected element in a different color
   unsigned short selected;
 
@@ -46,19 +45,16 @@ private :
   void drawHead();
 };
 
-
-class Viewer : public QGLViewer
-{
-protected :
+class Viewer : public QGLViewer {
+protected:
   virtual void draw();
   virtual void init();
   virtual void drawWithNames();
-  virtual void postSelection(const QPoint& point);
+  virtual void postSelection(const QPoint &point);
   virtual QString helpString() const;
 
   void initSpotLight();
 
-private :
+private:
   Luxo luxo;
 };
-
