@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -23,15 +23,16 @@
 #include "QGLViewer/constraint.h"
 #include "object.h"
 
-class ManipulatedFrameSetConstraint : public qglviewer::Constraint
-{
+class ManipulatedFrameSetConstraint : public qglviewer::Constraint {
 public:
-	void clearSet();
-	void addObjectToSet(Object* o);
+  void clearSet();
+  void addObjectToSet(Object *o);
 
-	virtual void constrainTranslation(qglviewer::Vec &translation, qglviewer::Frame *const frame);
-	virtual void constrainRotation(qglviewer::Quaternion &rotation, qglviewer::Frame *const frame);
+  virtual void constrainTranslation(qglviewer::Vec &translation,
+                                    qglviewer::Frame *const frame);
+  virtual void constrainRotation(qglviewer::Quaternion &rotation,
+                                 qglviewer::Frame *const frame);
 
-private :
-	QList<Object*> objects_;
+private:
+  QList<Object *> objects_;
 };
