@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -23,26 +23,25 @@
 #include "QGLViewer/qglviewer.h"
 #include "object.h"
 
-class Viewer : public QGLViewer
-{
+class Viewer : public QGLViewer {
 public:
   Viewer();
 
-protected :
+protected:
   virtual void draw();
   virtual void init();
   virtual QString helpString() const;
 
   // Selection functions
   virtual void drawWithNames();
-  virtual void endSelection(const QPoint&);
+  virtual void endSelection(const QPoint &);
 
   // Mouse events functions
   virtual void mousePressEvent(QMouseEvent *e);
   virtual void mouseMoveEvent(QMouseEvent *e);
   virtual void mouseReleaseEvent(QMouseEvent *e);
 
-private :
+private:
   void startManipulation();
   void drawSelectionRectangle() const;
   void addIdToSelection(int id);
@@ -55,6 +54,6 @@ private :
   enum SelectionMode { NONE, ADD, REMOVE };
   SelectionMode selectionMode_;
 
-  QList<Object*> objects_;
+  QList<Object *> objects_;
   QList<int> selection_;
 };
