@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -24,24 +24,22 @@
 #include <qapplication.h>
 #include <qsplitter.h>
 
-int main(int argc, char** argv)
-{
-  QApplication application(argc,argv);
+int main(int argc, char **argv) {
+  QApplication application(argc, argv);
 
   // Create Splitters
-  QSplitter *hSplit  = new QSplitter(Qt::Vertical);
+  QSplitter *hSplit = new QSplitter(Qt::Vertical);
   QSplitter *vSplit1 = new QSplitter(hSplit);
   QSplitter *vSplit2 = new QSplitter(hSplit);
 
   // Create the scene
-  Scene* s = new Scene();
+  Scene *s = new Scene();
 
   // Instantiate the viewers.
-  Viewer side  (s,0,vSplit1);
-  Viewer top   (s,1,vSplit1, &side);
-  Viewer front (s,2,vSplit2, &side);
-  Viewer persp (s,3,vSplit2, &side);
-
+  Viewer side(s, 0, vSplit1);
+  Viewer top(s, 1, vSplit1);
+  Viewer front(s, 2, vSplit2);
+  Viewer persp(s, 3, vSplit2);
 
   hSplit->setWindowTitle("multiView");
 
