@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,22 +22,18 @@
 
 #include <QGLViewer/qglviewer.h>
 
-class Scene
-{
+class Scene {
 public:
   void draw() const;
 };
 
-
-class Viewer : public QGLViewer
-{
+class Viewer : public QGLViewer {
 public:
-  Viewer(const Scene* const s, int type, QWidget* parent, const QGLWidget* shareWidget=NULL);
+  Viewer(const Scene *const s, int type, QWidget *parent);
 
-protected :
+protected:
   virtual void draw();
 
 private:
-  const Scene* const scene_;
+  const Scene *const scene_;
 };
-
