@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -25,12 +25,11 @@
 class QPaintEvent;
 class QPainter;
 
-class Viewer : public QGLViewer
-{
-public :
-  Viewer(QWidget* parent = 0);
+class Viewer : public QGLViewer {
+public:
+  Viewer(QWidget *parent = 0);
 
-protected :
+protected:
   virtual void draw();
   virtual void init();
   void drawOverpaint(QPainter *painter);
@@ -38,7 +37,7 @@ protected :
   virtual void paintGL() { update(); };
   virtual void paintEvent(QPaintEvent *event);
   // Could be overloaded to defer final initializations
-  //virtual void showEvent(QShowEvent *event);
+  // virtual void showEvent(QShowEvent *event);
 
   virtual QString helpString() const;
 };
