@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -23,14 +23,13 @@
 #include <QGLViewer/qglviewer.h>
 #include <qcolor.h>
 
-class Viewer : public QGLViewer
-{
-protected :
+class Viewer : public QGLViewer {
+protected:
   virtual void init();
   virtual void draw();
   virtual QString helpString() const;
 
-private :
+private:
   void drawSaucer() const;
 
   static const int nbSaucers = 10;
