@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -20,27 +20,29 @@
 
 *****************************************************************************/
 
+#include "cameraViewer.h"
 #include "standardCamera.h"
 #include "viewer.h"
-#include "cameraViewer.h"
 
 #include <QApplication>
 #include <QGLViewer/manipulatedCameraFrame.h>
 
-int main(int argc, char** argv)
-{
-  QApplication application(argc,argv);
+int main(int argc, char **argv) {
+  QApplication application(argc, argv);
 
   // Instantiate the two viewers.
-  StandardCamera* sc = new StandardCamera();
+  StandardCamera *sc = new StandardCamera();
   Viewer viewer(sc);
   CameraViewer cviewer(sc);
 
   // Make sure every v camera movement updates the camera viewer
-  QObject::connect(viewer.camera()->frame(), SIGNAL(manipulated()), &cviewer, SLOT(updateGL()));
-  QObject::connect(viewer.camera()->frame(), SIGNAL(spun()), &cviewer, SLOT(updateGL()));
+  QObject::connect(viewer.camera()->frame(), SIGNAL(manipulated()), &cviewer,
+                   SLOT(updateGL()));
+  QObject::connect(viewer.camera()->frame(), SIGNAL(spun()), &cviewer,
+                   SLOT(updateGL()));
   // Also update on camera change (type or mode)
-  QObject::connect(&viewer, SIGNAL(cameraChanged()), &cviewer, SLOT(updateGL()));
+  QObject::connect(&viewer, SIGNAL(cameraChanged()), &cviewer,
+                   SLOT(updateGL()));
 
   viewer.setWindowTitle("standardCamera");
   cviewer.setWindowTitle("Camera viewer");
