@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -22,9 +22,8 @@
 
 #include <QGLViewer/camera.h>
 
-class StandardCamera : public qglviewer::Camera
-{
-public :
+class StandardCamera : public qglviewer::Camera {
+public:
   StandardCamera();
 
   virtual qreal zNear() const;
@@ -34,9 +33,10 @@ public :
   bool isStandard() { return standard; }
 
   void changeOrthoFrustumSize(int delta);
-  virtual void getOrthoWidthHeight(GLdouble &halfWidth, GLdouble &halfHeight) const;
+  virtual void getOrthoWidthHeight(GLdouble &halfWidth,
+                                   GLdouble &halfHeight) const;
 
-private :
+private:
   bool standard;
   float orthoSize;
 };
