@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2014 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.6.3.
+ This file is part of the QGLViewer library version 2.8.0.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -24,24 +24,23 @@
 
 class StandardCamera;
 
-class Viewer : public QGLViewer
-{
-Q_OBJECT
+class Viewer : public QGLViewer {
+  Q_OBJECT
 
-public :
-  Viewer(StandardCamera* camera);
+public:
+  Viewer(StandardCamera *camera);
 
-public :
- Q_SIGNALS :
+public:
+Q_SIGNALS:
   void cameraChanged();
 
-protected :
+protected:
   virtual void draw();
   virtual void init();
   virtual QString helpString() const;
   virtual void keyPressEvent(QKeyEvent *e);
-  virtual void 	wheelEvent (QWheelEvent *e);
+  virtual void wheelEvent(QWheelEvent *e);
 
-private :
+private:
   void showMessage();
 };
